@@ -1,9 +1,11 @@
 {-# LANGUAGE CPP #-}
 {-# LANGUAGE EmptyDataDecls #-}
 {-# LANGUAGE FlexibleContexts #-}
+{-# LANGUAGE FlexibleInstances #-}
 {-# LANGUAGE MagicHash #-}
 {-# LANGUAGE StandaloneDeriving #-}
 {-# LANGUAGE TemplateHaskell #-}
+{-# LANGUAGE TypeFamilies #-}
 {-# LANGUAGE UndecidableInstances #-}
 module Foo where
 
@@ -41,9 +43,27 @@ data Unboxed = Unboxed {
 newtype Fix f = In { out :: f (Fix f) }
 deriving instance Show (f (Fix f)) => Show (Fix f)
 
+#if MIN_VERSION_template_haskell(2,7,0)
+data family   Fam a b c
+data instance Fam a Int Char
+  = FamPrefix1 a Char
+  | FamPrefix2 a
+  | FamRec { famField :: a }
+  | a :%%: a
+  deriving Show
+data instance Fam a Bool Bool = FamInstBool a Bool
+  deriving Show
+#endif
+
 $(deriveLift ''Foo)
 $(deriveLift ''Rec)
 $(deriveLift ''Empty)
 $(deriveLift ''Unboxed)
 instance Lift (f (Fix f)) => Lift (Fix f) where
   lift = $(makeLift ''Fix)
+
+#if MIN_VERSION_template_haskell(2,7,0)
+$(deriveLift 'FamPrefix1)
+instance (Eq a, Lift a) => Lift (Fam a Bool Bool) where
+  lift = $(makeLift 'FamInstBool)
+#endif
